==> haskell-skylighting-format-ansi-0.1-284-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-9GfMCuPkCOuZA5VWY1m35
key:                  skylighting-format-ansi-0.1-9GfMCuPkCOuZA5VWY1m35
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  d395a52b150da83797fbc97d4793a5f4
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-9GfMCuPkCOuZA5VWY1m35
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    binary-0.8.9.1 colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD containers-0.6.7
    skylighting-core-0.14.3-7mhH9r2pWCw3xU0g23Jkur text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-285-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-4uUy0xDmmKzXdJU99LoTT
key:                  skylighting-format-ansi-0.1-4uUy0xDmmKzXdJU99LoTT
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  9f72fc24c8b39d387c2599aa40e75840
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-4uUy0xDmmKzXdJU99LoTT
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh base-4.18.2.1
    binary-0.8.9.1 colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z containers-0.6.7
    skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
